View source: R/scale_fill_mrc.R
Fill scale constructor for mrc colors
1 2 | scale_fill_mrc(palette = "primary", discrete = TRUE, reverse = FALSE,
...)
|
palette |
Character name of palette in mrc_palettes |
discrete |
Boolean indicating whether color aesthetic is discrete or not |
reverse |
Boolean indicating whether the palette should be reversed |
... |
Additional arguments passed to discrete_scale() or scale_fill_gradientn(), used respectively when discrete is TRUE or FALSE |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.